==> ZenTaoPMS.max2.0.rc1.php5.3_5.6.zip: zentaopms/module/milestone/lang/zh-cn.php <==
<?php
$lang->milestone->common      = '项目里程碑报告';
$lang->milestone->index       = '报告首页';
$lang->milestone->title       = '里程碑报告';
$lang->milestone->name        = '里程碑名称';
$lang->milestone->stage       = '里程碑阶段';
$lang->milestone->save        = '保存';

$lang->milestone->indexAction = '里程碑报告';

$lang->milestone->startedWeeks  = '开始周数';
$lang->milestone->finishedWeeks = '结束周数';
$lang->milestone->offset        = '里程碑工期偏差';

$lang->milestone->processCommon = '项目当前进展状况';
$lang->milestone->process       = '项目进度';
$lang->milestone->executionCost   = '项目成本';
$lang->milestone->toNow         = '到目前为止';
$lang->milestone->targetRange   = '目标控制范围';
$lang->milestone->ge            = '大于等于';
$lang->milestone->le            = '小于等于';
$lang->milestone->analysis      = '分析结果';
$lang->milestone->PV            = '计划完成的工作(PV)';
$lang->milestone->EV            = '实际完成的工作(EV)';
$lang->milestone->AC            = '实际花费的成本(AC)';
$lang->milestone->SPI           = '项目进度绩效(SPI)';
$lang->milestone->CPI           = '项目成本绩效(CPI)';
$lang->milestone->SV            = '进度偏差率(SV%)';
$lang->milestone->CV            = '成本偏差率(CV%)';

$lang->milestone->workHours   = '工作量（人时）';
$lang->milestone->allStage    = '工程阶段';
$lang->milestone->devHours    = '研发工作量';
$lang->milestone->toHours     = '返工工作量';
$lang->milestone->reviewHours = '评审工作量';
$lang->milestone->qaHours     = '测试工作量';
$lang->milestone->rowSummary  = '工作量小计';
$lang->milestone->rowPercent  = '分布百分比(%)';
$lang->milestone->colPercent  = '占工作量百分比(%)';
$lang->milestone->colSummary  = '总和';
$lang->milestone->qatoDev     = '测试研发比';

$lang->milestone->executionRisk     = '5.项目风险(优先最高的前五项风险)';
$lang->milestone->riskCountermove = '风险对策';
$lang->milestone->riskDescriptio  = '风险描述';
$lang->milestone->riskPossibility = '可能性';
$lang->milestone->riskSeriousness = '严重性';
$lang->milestone->riskFactor      = '风险系数';
$lang->milestone->riskMeasures    = '风险对策';
$lang->milestone->riskAccumulate  = '累积的高风险';

$lang->milestone->otherIssue       = '其它问题';
$lang->milestone->issueSolutions   = '问题及解决建议';
$lang->milestone->issueDescription = '问题描述';
$lang->milestone->needHelp         = '是否需要高层支持';
$lang->milestone->issuePropose     = '解决建议';

$lang->milestone->demandStatus     = '4.用户需求状况分析';
$lang->milestone->storyUnit        = '单位:Item';
$lang->milestone->engineeringStage = '工程阶段';
$lang->milestone->rateChange       = '需求变化率';
$lang->milestone->originalStory    = '原始需求数量';
$lang->milestone->modifyNumber     = '变更后需求总数';
$lang->milestone->changeStory      = '变更的需求数';

$lang->milestone->paogressForecast   = '项目进展预测';
$lang->milestone->duration           = '工期(天)';
$lang->milestone->cost               = '成本(人时)';
$lang->milestone->forecastResults    = '预测结果分析';
$lang->milestone->plannedValue       = '计划值';
$lang->milestone->predictedValue     = '预测值';
$lang->milestone->predictedValueDesc = '计算公式：如果项目进度绩效(SPI)=0，那么预测值=0，否则，预测值=计划值 除以 项目进度绩效(SPI)';
$lang->milestone->periodDeviation    = '工期偏差';
$lang->milestone->costDeviation      = '成本偏差';
$lang->milestone->nextStage          = '下一里程碑阶段';
$lang->milestone->overallProject     = '项目总体';
$lang->milestone->corrective         = '纠偏措施';
$lang->milestone->timeOverrun        = '总工期将超出:%s天。';
$lang->milestone->costOverrun        = '总成本将超出:%s个单位。';
$lang->milestone->saveOtherProblem   = '保存其他问题';

$lang->milestone->chart = new stdclass();
$lang->milestone->chart->title    = '到目前为止项目进展趋势图';
$lang->milestone->chart->time     = '第';
$lang->milestone->chart->week     = '周';
$lang->milestone->chart->month    = '月';
$lang->milestone->chart->workhour = '研发工作量分析图';

$lang->milestone->otherproblem      = '6.其它问题';
$lang->milestone->problemandsuggest = '问题及解决建议';
$lang->milestone->suggest           = '解决建议';
$lang->milestone->needhelp          = '是否需要高层支持？';
$lang->milestone->prodescr          = '问题描述';

$lang->milestone->quality = new stdclass();
$lang->milestone->quality->total         = '合计';
$lang->milestone->quality->identify      = '缺陷识别阶段';
$lang->milestone->quality->injection     = '缺陷注入阶段';
$lang->milestone->quality->scale         = '规模';
$lang->milestone->quality->identifyRate       = '缺陷识别率';
$lang->milestone->quality->injectionRate      = '缺陷注入率';

$lang->milestone->options  = '操作';

==> ZenTaoPMS.max2.7.php5.3_5.6.zip: zentaopms/module/milestone/lang/zh-cn.php <==
<?php
$lang->milestone->common      = '项目里程碑报告';
$lang->milestone->index       = '报告首页';
$lang->milestone->title       = '里程碑报告';
$lang->milestone->name        = '里程碑名称';
$lang->milestone->stage       = '里程碑阶段';
$lang->milestone->save        = '保存';

$lang->milestone->indexAction = '里程碑报告';

$lang->milestone->startedWeeks  = '开始周数';
$lang->milestone->finishedWeeks = '结束周数';
$lang->milestone->offset        = '里程碑工期偏差';

$lang->milestone->processCommon = '项目当前进展状况';
$lang->milestone->process       = '项目进度';
$lang->milestone->executionCost   = '项目成本';
$lang->milestone->toNow         = '到目前为止';
$lang->milestone->targetRange   = '目标控制范围';
$lang->milestone->ge            = '大于等于';
$lang->milestone->le            = '小于等于';
$lang->milestone->analysis      = '分析结果';
$lang->milestone->PV            = '计划完成的工作(PV)';
$lang->milestone->EV            = '实际完成的工作(EV)';
$lang->milestone->AC            = '实际花费的成本(AC)';
$lang->milestone->SPI           = '项目进度绩效(SPI)';
$lang->milestone->CPI           = '项目成本绩效(CPI)';
$lang->milestone->SV            = '进度偏差率(SV%)';
$lang->milestone->CV            = '成本偏差率(CV%)';

$lang->milestone->workHours   = '工作量（人时）';
$lang->milestone->allStage    = '工程阶段';
$lang->milestone->devHours    = '研发工作量';
$lang->milestone->toHours     = '返工工作量';
$lang->milestone->reviewHours = '评审工作量';
$lang->milestone->qaHours     = '测试工作量';
$lang->milestone->rowSummary  = '工作量小计';
$lang->milestone->rowPercent  = '分布百分比(%)';
$lang->milestone->colPercent  = '占工作量百分比(%)';
$lang->milestone->colSummary  = '总和';
$lang->milestone->qatoDev     = '测试研发比';

$lang->milestone->executionRisk     = '5.项目风险(优先最高的前五项风险)';
$lang->milestone->riskCountermove = '风险对策';
$lang->milestone->riskDescriptio  = '风险描述';
$lang->milestone->riskPossibility = '可能性';
$lang->milestone->riskSeriousness = '严重性';
$lang->milestone->riskFactor      = '风险系数';
$lang->milestone->riskMeasures    = '风险对策';
$lang->milestone->riskAccumulate  = '累积的高风险';

$lang->milestone->otherIssue       = '其它问题';
$lang->milestone->issueSolutions   = '问题及解决建议';
$lang->milestone->issueDescription = '问题描述';
$lang->milestone->needHelp         = '是否需要高层支持';
$lang->milestone->issuePropose     = '解决建议';

$lang->milestone->demandStatus     = '4.用户需求状况分析';
$lang->milestone->storyUnit        = '单位:Item';
$lang->milestone->engineeringStage = '工程阶段';
$lang->milestone->rateChange       = '需求变化率';
$lang->milestone->originalStory    = '原始需求数量';
$lang->milestone->modifyNumber     = '变更后需求总数';
$lang->milestone->changeStory      = '变更的需求数';

$lang->milestone->paogressForecast   = '项目进展预测';
$lang->milestone->duration           = '工期(天)';
$lang->milestone->cost               = '成本(人时)';
$lang->milestone->forecastResults    = '预测结果分析';
$lang->milestone->plannedValue       = '计划值';
$lang->milestone->predictedValue     = '预测值';
$lang->milestone->predictedValueDesc = '计算公式：如果项目进度绩效(SPI)=0，那么预测值=0，否则，预测值=计划值 除以 项目进度绩效(SPI)';
$lang->milestone->periodDeviation    = '工期偏差';
$lang->milestone->costDeviation      = '成本偏差';
$lang->milestone->nextStage          = '下一里程碑阶段';
$lang->milestone->overallProject     = '项目总体';
$lang->milestone->corrective         = '纠偏措施';
$lang->milestone->timeOverrun        = '总工期将超出:%s天。';
$lang->milestone->costOverrun        = '总成本将超出:%s个单位。';
$lang->milestone->saveOtherProblem   = '保存其他问题';

$lang->milestone->chart = new stdclass();
$lang->milestone->chart->title    = '到目前为止项目进展趋势图';
$lang->milestone->chart->time     = '第';
$lang->milestone->chart->week     = '周';
$lang->milestone->chart->month    = '月';
$lang->milestone->chart->workhour = '研发工作量分析图';

$lang->milestone->otherproblem      = '6.其它问题';
$lang->milestone->problemandsuggest = '问题及解决建议';
$lang->milestone->suggest           = '解决建议';
$lang->milestone->needhelp          = '是否需要高层支持？';
$lang->milestone->prodescr          = '问题描述';

$lang->milestone->reviewHoursTip = '评审工作量 = 评审时长 * 评审人数';
$lang->milestone->toHoursTip     = '返工工作量统计的是研发任务被激活之后，重新消耗的工时';

$lang->milestone->quality = new stdclass();
$lang->milestone->quality->total         = '合计';
$lang->milestone->quality->identify      = '缺陷识别阶段';
$lang->milestone->quality->injection     = '缺陷注入阶段';
$lang->milestone->quality->scale         = '规模';
$lang->milestone->quality->identifyRate  = '缺陷识别率';
$lang->milestone->quality->injectionRate = '缺陷注入率';

$lang->milestone->options  = '操作';
